This package exists solely as a security proof of concept demonstrating the risks of unmaintained or abandoned package names in public package registries (PyPI).

The purpose of this release is to show that arbitrary code execution is possible when a previously unmaintained package name is reclaimed and installed by downstream users or automated systems.